@@ -8,7 +8,7 @@ import sys
 import unittest
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 
-from youtube_dlc.jsinterp import JSInterpreter
+from yt_dlp.jsinterp import JSInterpreter
 
 
 class TestJSInterpreter(unittest.TestCase):
