@@ -10,7 +10,7 @@ sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from test.helper import FakeYDL, md5
 
 
-from youtube_dlc.extractor import (
+from yt_dlp.extractor import (
     YoutubeIE,
     DailymotionIE,
     TEDIE,
